==> 0.0.35.tar.gz: lib/widget/appbar/custom_app_bar_arrow_transparent.dart <==

import 'package:flutter/material.dart';

import '../../common/values/sizes.dart';
import '../custom/custom_icon.dart';
import '../dialog/custom_will_pop_back.dart';
import '../text/custom_text_medium_bold_field.dart';

class CustomAppBarArrowTransparent extends StatelessWidget {
  final String? title;
  final Widget? tabBarMenu;
  final Widget? tabBarMenuRight;
  final bool? isWarning;
  final Color? textColor;

  const CustomAppBarArrowTransparent(
      {this.title,
      this.tabBarMenu,
      this.textColor,
      this.isWarning = false,
      this.tabBarMenuRight});

  @override
  Widget build(BuildContext context) {
    return Container(
      color: Colors.transparent,
      child: Column(
        children: [
          SafeArea(
            maintainBottomViewPadding: false,
            bottom: false,
            child: Padding(
              padding: EdgeInsets.only(left: 10),
              child: SizedBox(
                height: Sizes.HEIGHT_52,
                width: Sizes.width(context),
                child: GestureDetector(
                  onTap: () => CustomWillPopBack.Pop(context, isWarning),
                  child: Row(
                    crossAxisAlignment: CrossAxisAlignment.center,
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: <Widget>[
                      Expanded(
                        child: Row(
                          children: [
                            Container(
                                width: Sizes.WIDTH_40,
                                height: Sizes.HEIGHT_40,
                                decoration: BoxDecoration(
                                    color: Colors.grey.withOpacity(0.2),
                                    borderRadius: BorderRadius.circular(100)),
                                child: Padding(
                                  padding: const EdgeInsets.only(right: 4),
                                  child: CustomIcon(
                                    icon: Icons.keyboard_arrow_left_outlined,
                                    color: textColor ?? Colors.black,
                                    size: 36,
                                  ),
                                )),
                            if (title != null) ...[
                              Expanded(
                                child: CustomTextMediumBoldField(
                                  label: title,
                                  color: textColor,
                                ),
                              ),
                            ]
                          ],
                        ),
                      ),
                      Flexible(
                        child: tabBarMenuRight ?? Container(),
                      )
                    ],
                  ),
                ),
              ),
            ),
          ),
          tabBarMenu ?? Container(),
        ],
      ),
    );
  }
}

==> 0.0.37.tar.gz: lib/widget/appbar/custom_app_bar_arrow_transparent.dart <==

import 'package:flutter/material.dart';

import '../../common/values/sizes.dart';
import '../custom/custom_icon.dart';
import '../dialog/custom_will_pop_back.dart';
import '../text/custom_text_medium_bold_field.dart';

class CustomAppBarArrowTransparent extends StatelessWidget {
  final String? title;
  final Widget? tabBarMenu;
  final Widget? tabBarMenuRight;
  final bool? isWarning;
  final Color? textColor;

  const CustomAppBarArrowTransparent(
      {this.title,
      this.tabBarMenu,
      this.textColor,
      this.isWarning = false,
      this.tabBarMenuRight});

  @override
  Widget build(BuildContext context) {
    return Container(
      color: Colors.transparent,
      child: Column(
        children: [
          SafeArea(
            maintainBottomViewPadding: false,
            bottom: false,
            child: Padding(
              padding: EdgeInsets.only(left: 10),
              child: SizedBox(
                height: Sizes.HEIGHT_52,
                width: Sizes.width(context),
                child: GestureDetector(
                  onTap: () => CustomWillPopBack.Pop(context, isWarning),
                  child: Row(
                    crossAxisAlignment: CrossAxisAlignment.center,
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: <Widget>[
                      Expanded(
                        child: Row(
                          children: [
                            Container(
                                width: Sizes.WIDTH_40,
                                height: Sizes.HEIGHT_40,
                                decoration: BoxDecoration(
                                    color: Colors.black87.withOpacity(0.2),
                                    borderRadius: BorderRadius.circular(100)),
                                child: Padding(
                                  padding: const EdgeInsets.only(right: 4),
                                  child: CustomIcon(
                                    icon: Icons.keyboard_arrow_left_outlined,
                                    color: textColor ?? Colors.white,
                                    size: 36,
                                  ),
                                )),
                            if (title != null) ...[
                              Expanded(
                                child: CustomTextMediumBoldField(
                                  label: title,
                                  color: textColor,
                                ),
                              ),
                            ]
                          ],
                        ),
                      ),
                      Flexible(
                        child: tabBarMenuRight ?? Container(),
                      )
                    ],
                  ),
                ),
              ),
            ),
          ),
          tabBarMenu ?? Container(),
        ],
      ),
    );
  }
}
